Documentation
¶
Overview ¶
Package wire contains Alluxio file system wire types.
Index ¶
Constants ¶
const ( // BitsNone represents no access. BitsNone Bits = "NONE" // BitsExecute represent execute access. BitsExecute = "EXECUTE" // BitsWrite represents write access. BitsWrite = "WRITE" // BitsWriteExecute represents write and execute access. BitsWriteExecute = "WRITE_EXECUTE" // BitsRead represents read access. BitsRead = "READ" // BitsReadExecute represents read and execute access. BitsReadExecute = "READ_EXECUTE" // BitsReadWrite represents read and write access. BitsReadWrite = "READ_WRITE" // BitsAll represents read, write, and execute access BitsAll = "ALL" )
const ( // LoadMetadataTypeNever means metadata should never be loaded. LoadMetadataTypeNever LoadMetadataType = "Never" // LoadMetadataTypeOnce means metadata should be loaded once. LoadMetadataTypeOnce = "Once" // LoadMetadataTypeAlways means metadata should always be loaded. LoadMetadataTypeAlways = "Always" )
const ( // ReadTypeNoCache means data will be not cached. ReadTypeNoCache ReadType = "NO_CACHE" // ReadTypeCache means data will be cached. ReadTypeCache = "CACHE" // ReadTypeCachePromote mans data will be cached in the top tier. ReadTypeCachePromote = "CACHE_PROMOTE" )
const ( // WriteTypeMustCache means the data will be stored in Alluxio. WriteTypeMustCache WriteType = "MUST_CACHE" // WriteTypeCacheThrough means the data will be stored in Alluxio and // synchronously written to UFS. WriteTypeCacheThrough = "CACHE_THROUGH" // WriteTypeThrough means the data will be sychrounously written to UFS. WriteTypeThrough = "THROUGH" // WriteTypeAsyncThrough means the data will be stored in Alluxio and // asynchrounously written to UFS. WriteTypeAsyncThrough = "ASYNC_THROUGH" // WriteTypeNone means the data will no be stored. WriteTypeNone = "NONE" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BlockInfo ¶
type BlockInfo struct {
// BlockID is the block id.
BlockID int64
// Length is the block length.
Length int64
// Locations holds the block locations.
Locations []BlockLocation
}
BlockInfo represents a block's information.
type BlockLocation ¶
type BlockLocation struct {
// WorkerID is the worker id.
WorkerID int64
// WorkerAddress is the worker network address.
WorkerAddress WorkerNetAddress
// TierAlias is the tier alias.
TierAlias string
}
BlockLocation represents a block's location.
type FileBlockInfo ¶
type FileBlockInfo struct {
// BlockInfo is the block information
BlockInfo BlockInfo
// Offset is the file offset.
Offset int64
// UfsLocations holds the UFS locations.
UfsLocations []string
}
FileBlockInfo represents a file block's information.
type FileInfo ¶
type FileInfo struct {
// BlockIds holds the block ids.
BlockIds []int64
// BlockSizeBytes is the block size (in bytes).
BlockSizeBytes int64
// Cacheable determines whether the file is cacheable.
Cacheable bool
// Completed determines whether the file is completed.
Completed bool
// CreationTimesMs is the creation time (in milliseconds).
CreationTimeMs int64
// FileBlockInfos holds the file block information.
FileBlockInfos []FileBlockInfo
// FileID is the file id.
FileID int64
// Folder determines whether the file is a folder.
Folder bool
// Group is the group.
Group string
// InMemoryPercentage represents the in-memory percentage.
InMemoryPercentage int32
// LastModificationTimeMs is the last modification time (in milliseconds).
LastModificationTimeMs int64
// Length is the file length.
Length int64
// Name is the file name.
Name string
// Path is the file path.
Path string
// Persisted determines whether file is persisted.
Persisted bool
// PersistenceState represents the persistence state.
PersistenceState string
// Pinned determines whether the file is pinned.
Pinned bool
// Mode is the access mode.
Mode int32
// MountPoint determines whether the file is a mount point.
MountPoint bool
// Owner is the owner.
Owner string
// TTL is the time-to-live window.
TTL int64
// TTLAction si the time-to-live action.
TTLAction string
// UfsPath is the UFS path.
UfsPath string
}
FileInfo represents a file's information.
type LoadMetadataType ¶
type LoadMetadataType string
LoadMetadataType represents the load metadata type.
type Mode ¶
type Mode struct {
// OwnerBits represents the owner access mode
OwnerBits Bits `json:"ownerBits"`
// GroupBits represents the group access mode
GroupBits Bits `json:"groupBits"`
// OtherBits represents the other access mode
OtherBits Bits `json:"otherBits"`
}
Mode represents the file's access mode.
type TTLAction ¶
type TTLAction string
TTLAction represents a TTL action.
const ( // TTLActionDelete represents the action of deleting a path. TTLActionDelete TTLAction = "DELETE" // TTLActionFree represents the action of freeing a path. TTLActionFree = "FREE" )
Click to show internal directories.
Click to hide internal directories.